@@ -22,7 +22,7 @@
 
 Rcpp::CharacterVector icd9AddLeadingZeroes(Rcpp::CharacterVector icd9, bool isShort);
 Rcpp::CharacterVector icd9AddLeadingZeroesShort(Rcpp::CharacterVector icd9Short);
-Rcpp::String icd9AddLeadingZeroesMajorSingleShim(Rcpp::String mjr);
-Rcpp::CharacterVector icd9AddLeadingZeroesMajorShim(Rcpp::CharacterVector mjr);
+Rcpp::String icd9AddLeadingZeroesMajorSingle(Rcpp::String major);
+Rcpp::CharacterVector icd9AddLeadingZeroesMajor(Rcpp::CharacterVector major);
 
 #endif /* MANIP_H_ */
